@@ -1,4 +1,3 @@
 <pre>Sie müssen die Konfigurationseinstellung facebook_app_id nun setzen,
 sofern Sie das noch nicht getan haben.
-Eine Facebook APP-ID können Sie <a
-		href="https://developers.facebook.com/">hier erstellen</a>.</pre>
+Eine Facebook APP-ID können Sie <a href="https://developers.facebook.com/">hier erstellen</a>.</pre>
